==> bce-java-sdk-0.10.186-sources.jar: com/baidubce/services/bec/model/blb/GetBecBlbBackendBindingStsListRequest.java <==
/*
 * Copyright (c) 2020 Baidu.com, Inc. All Rights Reserved
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on
 * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations under the License.
 */
package com.baidubce.services.bec.model.blb;

import com.baidubce.auth.BceCredentials;
import com.baidubce.model.AbstractBceRequest;
import lombok.Data;

/**
 * The request for getting the binding BEC blb backend StatefulSet/VmReplicas list.
 */
@Data
public class GetBecBlbBackendBindingStsListRequest extends AbstractBceRequest {

    /**
     * the id of the blb.
     */
    private String blbId;

    /**
     * page number.
     */
    private Integer pageNo;

    /**
     * page size.
     */
    private Integer pageSize;

    /**
     * Key word.
     */
    private String keyword;

    /**
     * Configure request credential for the request.
     *
     * @param credentials a valid instance of BceCredentials.
     * @return GetInstanceRequest with credentials.
     */
    public GetBecBlbBackendBindingStsListRequest withRequestCredentials(BceCredentials credentials) {
        this.setRequestCredentials(credentials);
        return this;
    }
}

==> bce-java-sdk-0.10.363-sources.jar: com/baidubce/services/bec/model/blb/GetBecBlbBackendBindingStsListRequest.java <==
/*
 * Copyright (c) 2020 Baidu.com, Inc. All Rights Reserved
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on
 * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations under the License.
 */
package com.baidubce.services.bec.model.blb;

import com.baidubce.auth.BceCredentials;
import com.baidubce.model.AbstractBceRequest;
import lombok.Data;

/**
 * The request for getting the StatefulSet/VmReplicas list that can be bound by the designated BEC blb.
 */
@Data
public class GetBecBlbBackendBindingStsListRequest extends AbstractBceRequest {

    /**
     * the id of the blb.
     */
    private String blbId;

    /**
     * page number.
     */
    private int pageNo;

    /**
     * page size.
     */
    private int pageSize;

    /**
     * Key word type，default serviceId.
     */
    private String keywordType;

    /**
     * Key word.
     */
    private String keyword;

    /**
     * Configure request credential for the request.
     *
     * @param credentials a valid instance of BceCredentials.
     * @return GetInstanceRequest with credentials.
     */
    public GetBecBlbBackendBindingStsListRequest withRequestCredentials(BceCredentials credentials) {
        this.setRequestCredentials(credentials);
        return this;
    }
}
